smooth.pred <- function(data, rows) {
  mod <- loess(prc ~ t, data=data, span=0.2)
  if (missing(rows))    
    grid <- data.frame(t = data$t)
  else
    grid <- data.frame(t = seq(min(data$t), max(data$t), length=rows))
  grid$epoch = epoch(grid$t)
  prc <- stats::predict(mod, grid)
  prc
}

proc.data <- function(data) {
  # Strip zero-value rows
  data <- data[data$num != 0,]

  # Transform temporal scale
  data$epoch <- epoch(data$t)

  span = max(data$num) - min(data$num)
  data$prc <- (data$num - min(data$num)) / span * 100
  data
}

proc.data.pred <- function(data) {
  data <- proc.data(data)
  data$prc.pred <- smooth.pred(data)

  # Now create an estimate of the overall distribution, adjusted to
  # match the maxima/minima of the faceted estimate.
  data$prc.pred.abs <- smooth.pred(data.all, nrow(data))

  pred.min <- min(data$prc.pred)
  pred.range <- max(data$prc.pred) - pred.min
  pred.abs.range <- max(data$prc.pred.abs) - min(data$prc.pred.abs)
  
  # Align total prediction with faceted one:
  data$prc.pred.abs <- data$prc.pred.abs - min(data$prc.pred.abs)
  data$prc.pred.abs <- data$prc.pred.abs * (pred.range / pred.abs.range)
  data$prc.pred.abs <- data$prc.pred.abs + pred.min
  
  data
}

data.all <- read.csv('activity_all.data')
data.tag <- read.csv('activity_tag.data', as.is=TRUE)

# Build a custom factor:
data.tag$tag = factor(data.tag$tag, labels=c('< 18', '18-25', '26-35', '36-45', '46-55', '> 55'))

data.all <- proc.data(data.all)
data.tag <- do.call('rbind', by(data.tag, data.tag$tag, proc.data.pred))

# Plot the overall one:
p <- ggplot(data=data.all, aes(epoch, prc)) +
  geom_line(color='darkgray') +
  geom_smooth(color='darkblue', method='loess', span=0.2) +
  labs(x='Time of day', y='% of users') +
  scale_x_datetime(format='%H', major='6 hours', minor='2 hours')
ggsave('testpilot-time-of-day.png', plot=p)

# Plot the facets:
p <- ggplot(data.tag, aes(epoch, prc)) +
  geom_line(color='darkgray') +
  geom_line(mapping=aes(epoch, prc.pred.abs), color='blue') +
  geom_line(mapping=aes(epoch, prc.pred), color='darkblue') +
  labs(x='Time of day', y='% of users') +
  scale_x_datetime(format='%H', major='6 hours', minor='2 hours') +
  facet_wrap(~ tag, ncol=3)
ggsave('testpilot-time-of-day-facets.png', plot=p)

#  geom_smooth(data=data.all, mapping=aes(epoch, prc), color='blue') +
#  geom_smooth(color='darkblue', ) +
