#! /usr/bin/env python

import psycopg2
import sys
import TPDB

class UserActivity:
  def __init__(self, uid):
    self.uid = uid
    self.ivals = []
    self._start = None
    self._end = None

  def _store(self):
    # Since we fold multiple days into a single one, we need to
    # special-case midnight at this point. If the interval crosses it,
    # we turn it into two intervals, one ending at midnight and one
    # beginning.
    if self._end.day > self._start.day or \
          self._end.month > self._start.month or \
          self._end.year > self._start.year:
      mid = self._start.replace(hour=23, minute=59, second=59, microsecond=999999)
      self.ivals.append((self._start, mid))
      self._start = self._end.replace(hour=0, minute=0, second=0, microsecond=0)

    self.ivals.append((self._start, self._end))
    self._start = None
    self._end = None

  def add(self, ev, ts):
    if ev == 1 or ev == 4:
      if self._start != None:
        return
      self._start = ts

    if ev == 2 or ev == 3 or ev == 5: # going inactive
      if self._start == None:
        return
      self._end = ts
      self._store()

db = TPDB.Conn()
if not db.connect():
  sys.exit(1)
  
cur = db.cursor()

cur.execute('truncate activity');
db.commit()

cur.execute('select uid, eid, ts from ev where eid >= 1 and eid <= 5 order by uid, ts')
rows = cur.fetchall()

uid = None
usr = None
usrs = []

for row in rows:
  if row[0] != uid:
    if usr != None:
      usrs.append(usr)
    uid = row[0]
    usr = UserActivity(uid)
  usr.add(row[1], row[2])

for usr in usrs:
  for ival in usr.ivals:
    cur.execute('insert into activity (uid, t0, t1, d) values (%(uid)s, %(t0)s, %(t1)s, %(d)s)',
                {'uid': usr.uid, 't0': ival[0], 't1': ival[1], 'd': ival[0].strftime('%a')})
  db.commit()

