#! /usr/bin/env python

import optparse
import psycopg2
import sys
import TPDB

def process(clear=False, res='', tag=None, weekend=None):
    db = TPDB.Conn()
    if not db.connect():
      sys.exit(1)

    cur = db.cursor()
    active = 0
    starts = {}
    ends = {}
    destination='total_activity'

    where = []
    if len(res) > 0:
        where.append(res)
    if weekend == True:
        where.append("(d = 'Sat' or d = 'Sun')")
        destination='total_activity_we'
    elif weekend == False:
        where.append("(d != 'Sat' and d != 'Sun')")
        destination='total_activity_wd'

    if len(where) > 0:
        where = 'where ' + ' and '.join(where)
    else:
        where = ''

    if clear:
        cur.execute('truncate ' + destination)
        db.commit()

    cur.execute('select t0 from activity_trunc_labeled %s order by t0' % where)
    for row in cur.fetchall():
        active += 1
        starts[row[0]] = active

    active = 0
    cur.execute('select t1 from activity_trunc_labeled %s order by t1' % where)
    for row in cur.fetchall():
        active -= 1
        ends[row[0]] = active

    ts_idx = set(starts.keys()) | set(ends.keys())
    ts_idx = [key for key in ts_idx]
    ts_idx.sort()
    plus = 0
    minus = 0

    for ts in ts_idx:
        if ts in starts:
            plus = starts[ts]
        if ts in ends:
            minus = ends[ts]    
        cur.execute('insert into ' + destination + ' values (%(t)s, %(num)s, %(tag)s)',
                    {'t': ts, 'num': plus + minus, 'tag': tag})

    db.commit()

def run():
    formatter = optparse.IndentedHelpFormatter(max_help_position=50, width=100)
    parser = optparse.OptionParser(formatter=formatter)

    parser.add_option('-c', '--clear', action='store_true',
                      help='clear total_activity before insertions')
    parser.add_option('-r', '--restrict', 
                      help='restriction on selection from activity table')
    parser.add_option('-t', '--tag', 
                      help='tag to use on inserts into total_activity')
    parser.set_defaults(clear=False, restrict='', tag=None)
    
    options, args = parser.parse_args()

    process(clear=options.clear, res=options.restrict, tag=options.tag)
    process(clear=options.clear, res=options.restrict, tag=options.tag, weekend=True)
    process(clear=options.clear, res=options.restrict, tag=options.tag, weekend=False)

if __name__ == '__main__':
    run()
